# Speedcord
A simple discord API wrapper - without the bullshit

## Contributions
Some ideas of what we need in speedcord

- Cogs  
- Ability to only spawn select cogs  
- Automatically scale cogs when we gain guilds
- Make some simple typing functions
